function results=layet(E,U,H,La,l,p,a,xc,yc,l1,ls,xs,ys,zs,irqst)

% layer elastic theory (layet) for analysis of a 5 layer pavement
%
% variable name        description
% --------------  -----------------------------------------------------
% e1-e5           layer moduli, psi
% h1-h4           layer thicknesses, in
% u1-u5           layer poisson ratio
% la1-la3         layer interface; 1=no slip, >1=partial slip
% l               number of loaded areas
% p()             pressure, psi
% a()             radius of loaded area, in
% xc(),yc()       x,y co-ordinates of loaded areas, in
% l1              number of evaluation positions
% ls()            layer number for evaluation positions
% xs(),ys(),zs()  x,y,z co-ordinates of evaluation positions
%
% results(,)      array containing computed results[position,value]
%                 for 19 values:
%                 values 1-3 ==> sx,sy,sz
%                 values 4-6 ==> tyz,txz,txy
%                 values 7-9 ==> s1,s2,s3
%                 values 10-12 ==> eps1,eps2,eps3
%                 values 13-15 ==> ux,vy,wz
%                 value 19 ==> integration step
%
% irqst           request for: 1= stresses, strains, & displacements
%                              2= displacements only(integration
%                                 parameter will not depend on radial
%                                 offset distances)

%  Structural information


global prov;
global res;

prov=zeros(11,19);
res=zeros(11,19);

e1=E(1);   e2=E(2);   e3=E(3);   e4=E(4);   e5=E(5);
u1=U(1);   u2=U(2);   u3=U(3);   u4=U(4);   u5=U(5);
h1=H(1);   h2=H(2);   h3=H(3);   h4=H(4);   h5=H(5);
la1=La(1); la2=La(2); la3=La(3); la3=La(4);la3=La(5);

% ****** Evaluation positions now[x,y,z] *******

[z1,z2,z3,z4,xs,ys,zs,a,xc,yc]=echde(h1,h2,h3,h4,xs,ys,zs,a,...
    xc,yc,l,l1);

if(irqst ~= 2)
    rmax=0.;
    for  i=1:l1
        for  j=1:l
            r=sqrt((xc(j)-xs(i))^2+(yc(j)-ys(i))^2);
            if(r > rmax) rmax=r; end
        end
    end 
else
    rmax=1.;
end

min=e1;
if(e2 < min) min=e2; end;
if(e3 < min) min=e3; end;
if(e4 < min) min=e4; end;
if(e5 < min) min=e5; end;

if(la1 ~= 0. && la2 ~= 0.)
    if(e5>min) [p1,ml,m,a1,c1,a2,b2,c2,d2,a3,b3,c3,d3,a4,b4,c4,d4,pr,...
            w2,fl]=pas1(a,l,e1,e2,e3,e4,e5,u1,u2,u3,u4,u5,z1,z2,z3,z4,...
            la1,la2,la3,rmax); 
    end
    if(e5<=min) [p1,pr,ml]=pas2(e1,e5,u1,u5,a,l,rmax); 
    end
else
    p1=0.1;
end

%  *********** Computation ***********

if(la1~=0. && la2~=0.)
    [w1,m,m1]=vinit(l1,p1);
    finit(l,l1,zs,ls,e1,e2,e3,e4,e5,u1,u2,u3,u4,u5,p,a,m1);
else
    [w1,pr,m,m1]=vinit2(l1,p1);
    finit(l,l1,zs,ls,e1,e2,e3,e4,e5,u1,u2,u3,u4,u5,p,a,m1);
end;

kkk=0;

while(kkk==0)   %  loop start 

m=m+m1;

if(la1~=0. && la2~=0)
    [a1,c1,a2,b2,c2,d2,a3,b3,c3,d3,a4,b4,c4,d4,w2,fl]=const1(...
        m,e1,e2,e3,e4,e5,u1,u2,u3,u4,u5,z1,z2,z3,z4,la1,la2,la3,pr);
else
    [a1,c1,a2,b2,c2,d2,a3,b3,c3,d3,a4,b4,c4,d4,w2]=const2(...
        m,e1,e2,e3,e4,e5,u1,u2,u3,u4,u5,z1,z2,z3,z4,pr);
end

j1=besj1(l,m,a);

prov(:,1:9)=0.;

for  i=1:l1
    for  j=1:l
        r=sqrt((xc(j)-xs(i))^2+(yc(j)-ys(i))^2);
        alpha=0.;
        if(xc(j)~= xs(i) || yc(j)~= ys(i))
            alpha=atan2(ys(i)-yc(j),xs(i)-xc(j)); 
        end
        [j0,j2]=bj0j2(m,r);
        if(zs(i)==0.)
            surface(i,j,z1,a1,c1,u1,j0,j1,j2,m,p,a,r,alpha);
        else
            if(irqst~=2)
                 z=zs(i);
                 if(ls(i)==1)
                     couc1(i,j,z,p,a,j0,j1,j2,z1,u1,m,a1,c1,r,alpha); 
                 end
                 if(ls(i)==2)
                     couc2(i,j,z,p,a,j0,j1,j2,z1,z2,u2,e2,m,a2,b2,...
                         c2,d2,r,alpha);
                 end
                 if(ls(i)==3)
                     couc3(i,j,z,p,a,j0,j1,j2,z2,z3,u3,e3,m,a3,b3,...
                         c3,d3,r,alpha); 
                 end
                 if(ls(i)==4)
                     couc4(i,j,z,p,a,j0,j1,j2,z3,z4,u4,e4,m,a4,b4,...
                         c4,d4,r,alpha); 
                 end
             end    
        end
    end
end

if(la1~=0. && la2~=0.)
    w1=simps1(l1,w1,m1);
    if(w1==0)
        kkk=1;
        w1=1;
        if(w2==0)  
            [pr,m1]=modif1(pr,m1,l1,rmax);  
        end
        if(m<=ml)   
            w2=1;   
        end
        if(abs(fl)>0.0001)
            kkk=0;  
        end
    end
else
    w1=simps2(l1,w1,m1);
    if(w1~=1)
        kkk=1;
        if(w2==0)
            [pr,m1]=modif2(pr,m1,l1);
        end
        if(pr>0.000001)
            kkk=0;
        end
    end
end

end  %  loop end 

comsu(l,l1,a,p,u1,e1,xc,xs,yc,ys,zs);
ccou1(l,l1,ls,xc,xs,yc,ys,zs,a,p,u1,e1);

[z1,z2,z3,z4,xs,ys,zs,a,xc,yc]=echef(h1,z1,z2,z3,z4,xs,ys,zs,a,...
    xc,yc,l1,l);

results=imres(l1,ls,u1,u2,u3,u4,e1,e2,e3,e4,p1);

% ---------------------------------------------------------------------

function [w1,m,m1]=vinit(l1,p1)

%  initial values

global prov;
global res;

for  k=1:9
    for  i=1:l1
        prov(i,k)=0.;
        res(i,k)=0.;
    end
end;  

w1=1;
m=0.;
m1=p1;

% ---------------------------------------------------------------------

function [w1,pr,m,m1]=vinit2(l1,p1)

global prov;
global res;

for  k=1:9
    for  i=1:l1
        prov(i,k)=0.;
        res(i,k)=0.;
    end
end

w1=0;
pr=0.01;
m=0.;
m1=p1;

% ---------------------------------------------------------------------

function finit(l,l1,zs,ls,e1,e2,e3,e4,e5,u1,u2,u3,u4,u5,p,a,m1);

global res;

fw=e1*(1.+u2)/(e2*(1.+u1));
kw=e2*(1.+u3)/(e3*(1.+u2));
lw=e3*(1.+u4)/(e4*(1.+u3));
jw=e4*(1.+u5)/(e5*(1.+u4));

for  i=1:l1
    for  j=1:l
        if(ls(i)==1 & zs(i)==0.)
            res(i,1)=res(i,1)+p(j)*a(j)^2*m1/40.*3.*...
                (1.-(1.-u5)/(1.-u1)*fw*kw*lw*jw); 
        end
        if(ls(i)==1 & zs(i)~= 0.)
            res(i,1)=res(i,1)+p(j)*a(j)^2*m1*3./10.*(1.-u1)*...
                (1.-(1.-u5)/(1.-u1)*fw*kw*lw*jw); 
        end
        if(ls(i)==2)
            res(i,1)=res(i,1)-(1.+u2)*(1.-u5)*kw*lw*jw*...
                p(j)*a(j)^2*m1*3./10./e2; 
        end
        if(ls(i)==3)
            res(i,1)=res(i,1)-(1.+u3)*(1.-u5)*lw*jw*p(j)*...
                a(j)^2*m1*3./10./e3; 
        end
        if(ls(i)==4)
            res(i,1)=res(i,1)-(1.+u4)*(1.-u5)*jw*p(j)...
                *a(j)^2*m1*3./10./e4; 
        end
    end
end

% ---------------------------------------------------------------------

function w1=simps1(l1,w1,m1);

global prov;
global res;

switch(w1)
    case(1);   coef=5.;   w1=2;
    case(2);   coef=1.;   w1=3;
    case(3);   coef=6.;   w1=4;
    case(4);   coef=1.;   w1=5;
    case(5);   coef=5.;   w1=6;
    case(6);   coef=2.;   w1=0;
end

for  k=1:9
    for  i=1:l1
        res(i,k)=res(i,k)+prov(i,k)*coef*m1*3./10.;
    end
end 

% ---------------------------------------------------------------------

function w1=simps2(l1,w1,m1)

% function Simpson rule 

global prov;
global res;

if(w1==0)
    coef=4.;
    w1=1;
else
    coef=2.;
    w1=0;
end

for k=1:9
    for i=1:l1
        res(i,k)=res(i,k)+prov(i,k)*coef*m1/3.;
    end
end

% ---------------------------------------------------------------------

function [pr,m1]=modif1(pr,m1,l1,rmax)

% function for alternation of step computation

global prov;
global res;

m2=2.*m1;
pr=pr/2.;

if(rmax >= 2.5);
    p1l=0.5/rmax;
else
    p1l=0.2;
end

if(m2>=p1l)
    m2=p1l;
    pr=0;
end

for  k=1:9
    for  i=1:l1
        res(i,k)=res(i,k)+prov(i,k)*(m2-m1)*3./10.;
    end
end

m1=m2;

% ---------------------------------------------------------------------

function [pr,m1]=modif2(pr,m1,l1)

% function for alternation of step computation

global prov;
global res;

for  k=1:9
    for  i=1:l1
        res(i,k)=res(i,k)+prov(i,k)*m1/3.;
    end
end

pr=0.1*pr;
m1=2.0*m1;

