% Crack-prediction model
% Based on Florida Cracking Model

% Clean up
clear;clc;close all;

%% INITIATION
% Addpath
addpath .\ELT 


%% USER INPUTS

% Mixtur gradation, volumetrics and rheological properties

% gradation
% p34=; p38=; p4=; p200=;             % percent passing in 3/4(19mm), 3/8(9.5mm), number 4(4.75mm), number 200(0.075mm)

% Volumetrics
% Va=; Vbeff=;           % air void and effective asphalt content

% Rheological properties
% A=; VTS=;

% Pavement structural properties
% Hac=; Hb=; Hsb=; Hsg=;                % inch, thickness of AC, base, subbase, subgrade
% Eb=; Esb=; Esg=;                      % in psi, modulus of base, subbase, subgrade         

% Other inputs
% maat=;                 % mean annual air temperature in Fahiriniet
% Tref=;                  % Reference temperature in Fahirieniet
% time=;                 % Design Life (month)  
% t=;              % time of loading for AC stiffness prediction
% t1800=;         % time of loading for tensile strength prediction
% z=;            % level at which tensile strength and creep parameters should be calculated


% TRAFFIC AND RELIABILITY
% ESALs=;   % Traffic
% R=;       % reliability
% ERopt=eropt(ESALs,R);  %Run function to find Optimum Energyratio, ERopt


%% Subbase/Subgrade data (Thickness, Modulus, Poisson's, Layer-slip)
H(3:5)=[Hb Hsb Hsg]; E(3:5)=[Eb Esb Esg]; U(1:5)=[0.3 0.3 0.35 0.35 0.4];
La(1:5)=[1 1 1 1 1];

% mix parameters
mixparam=[p34; p38; p4; p200; Va; Vbeff; A; VTS];

% AC sublayers
H(1:2)=[0.25*Hac 0.75*Hac] ;

% load setup
k=1;    % single axle load configuration
[l1 ls l p a xc yc xs ys irqst]=load_setup(k);

%% MATERIAL DATA - AGED CONDITION 

St=tensile_strength(Tref,maat,mixparam,time,t1800,z); % unit in MPa

[D1 m]=creep_parameters(mixparam,maat,Tref,time,z);   % D1 in 1/psi

% Regression constant to find DElimit
CF=6.9103*10^7;

% Calculate DCSE limit
DElimit=CF*St*m*D1/(10^(3*(1 - m)));  % unit kJ/m^3
    
%% RESPONSE AND THICKNESS OPTIMIZATION
i=1
ER=0;  % Variable-Allocation

while ER < ERopt

    % Allocate layer modulii(psi)in preparation of LEA
    E(1:2)=AC_modulus(Tref,maat,mixparam,time,t,Hac);
    
   
    % RESPONSE
    
    % z-coordinate for stress-evaluation 
    zs(1:2)=H(1)+H(2)-.01;    
    
      
    
    % Linear elastic analysis
    response_returns=layet(E,U,H,La,l,p,a,xc,yc,l1,ls,xs,ys,zs,irqst);
        
    % DCSE min and ER
     Sigmamax=max(abs(response_returns(1,2)));
    f=0.0299*(6.36 - St)*(Sigmamax^-3.10) + 2.46*10^-8;
    DCSEmin=((m^2.98)*D1)/f;
    
    ER=DElimit/DCSEmin;
    
   
    % Increase (bottom) layer thickness by 0.1" (2.54 mm)
    
    Hac=Hac+0.1;
    H(1:2)=[0.25*Hac 0.75*Hac] ;
   
    
    i=i+1 %Index
end
 
Htot=Hac-0.1; %Last addition is substracted due to the mechanics of the while-loop

